==> boswars-2.3p0.tgz: share/boswars/scripts/cursors.lua <==
--     ____                _       __               
--    / __ )____  _____   | |     / /___ ___________
--   / __  / __ \/ ___/   | | /| / / __ `/ ___/ ___/
--  / /_/ / /_/ (__  )    | |/ |/ / /_/ / /  (__  ) 
-- /_____/\____/____/     |__/|__/\__,_/_/  /____/  
--                                              
--       A futuristic real-time strategy game.
--          This file is part of Bos Wars.
--
--      ui.lua - Define the widgets
--
--      (c) Copyright 2000 - 2006 by Lutz Sammer, Francois Beerten
--                     and Crestez Leonard.
--
--      This program is free software; you can redistribute it and/or modify
--      it under the terms of the GNU General Public License as published by
--      the Free Software Foundation; either version 2 of the License, or
--      (at your option) any later version.
--  
--      This program is distributed in the hope that it will be useful,
--      but WITHOUT ANY WARRANTY; without even the implied warranty of
--      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
--      GNU General Public License for more details.
--  
--      You should have received a copy of the GNU General Public License
--      along with this program; if not, write to the Free Software
--      Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
--
--      $Id: cursors.lua 8539 2007-02-07 19:13:10Z feb $

DefineCursor({
    Name = "cursor-glass",
    File = "general/magnifying_glass.png",
    HotSpot = {11, 11},
    Size = {34, 35}})

DefineCursor({
   Name = "cursor-cross",
   File = "general/small_green_cross.png",
   HotSpot = {8, 8},
   Size = {18, 18}})

DefineCursor({
   Name = "cursor-scroll",
   File = "general/cross.png",
   HotSpot = {15, 15},
   Size = {32, 32}})

DefineCursor({
   Name = "cursor-arrow-e",
   File = "general/arrow_E.png",
   HotSpot = {22, 10},
   Size = {32, 24}})

DefineCursor({
   Name = "cursor-arrow-ne",
   File = "general/arrow_NE.png",
   HotSpot = {20, 2},
   Size = {32, 24}})

DefineCursor({
   Name = "cursor-arrow-n",
   File = "general/arrow_N.png",
   HotSpot = {12, 2},
   Size = {32, 24}})

DefineCursor({
   Name = "cursor-arrow-nw",
   File = "general/arrow_NW.png",
   HotSpot = {2, 2},
   Size = {32, 24}})

DefineCursor({
   Name = "cursor-arrow-w",
   File = "general/arrow_W.png",
   HotSpot = {4, 10},
   Size = {32, 24}})

DefineCursor({
   Name = "cursor-arrow-s",
   File = "general/arrow_S.png",
   HotSpot = {12, 22},
   Size = {32, 24}})

DefineCursor({
   Name = "cursor-arrow-sw",
   File = "general/arrow_SW.png",
   HotSpot = {2, 18},
   Size = {32, 24}})

DefineCursor({
   Name = "cursor-arrow-se",
   File = "general/arrow_SE.png",
   HotSpot = {20, 18},
   Size = {32, 24}})

DefineCursor({
   Name = "cursor-point",
   File = "elites/ui/elites_claw.png",
   HotSpot = {1, 1}, 
   Size = {28, 32}})

DefineCursor({
   Name = "cursor-green-hair",
   File = "general/green.png",
   HotSpot = {15, 15},
   Size = {32, 32}})

DefineCursor({
   Name = "cursor-yellow-hair",
   File = "general/yellow.png",
   HotSpot = {15, 15},
   Size = {32, 32}})

DefineCursor({
   Name = "cursor-red-hair",
   File = "general/red.png",
   HotSpot = {15, 15},
   Size = {32, 32}})

==> boswars-2.6.tgz: share/boswars/scripts/cursors.lua <==
--     ____                _       __               
--    / __ )____  _____   | |     / /___ ___________
--   / __  / __ \/ ___/   | | /| / / __ `/ ___/ ___/
--  / /_/ / /_/ (__  )    | |/ |/ / /_/ / /  (__  ) 
-- /_____/\____/____/     |__/|__/\__,_/_/  /____/  
--                                              
--       A futuristic real-time strategy game.
--          This file is part of Bos Wars.
--
--      ui.lua - Define the widgets
--
--      (c) Copyright 2000 - 2008 by Lutz Sammer, Francois Beerten
--                     and Crestez Leonard.
--
--      This program is free software; you can redistribute it and/or modify
--      it under the terms of the GNU General Public License as published by
--      the Free Software Foundation; either version 2 of the License, or
--      (at your option) any later version.
--  
--      This program is distributed in the hope that it will be useful,
--      but WITHOUT ANY WARRANTY; without even the implied warranty of
--      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
--      GNU General Public License for more details.
--  
--      You should have received a copy of the GNU General Public License
--      along with this program; if not, write to the Free Software
--      Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
--

DefineCursor({
    Name = "cursor-glass",
    File = "graphics/ui/cursor-info.png",
    HotSpot = {1, 1},
    Size = {28, 32}})

DefineCursor({
   Name = "cursor-cross",
   File = "graphics/ui/cursors/small_green_cross.png",
   HotSpot = {8, 8},
   Size = {18, 18}})

DefineCursor({
   Name = "cursor-scroll",
   File = "graphics/ui/cursors/cross.png",
   HotSpot = {15, 15},
   Size = {32, 32}})

DefineCursor({
   Name = "cursor-arrow-e",
   File = "graphics/ui/cursors/arrow_E.png",
   HotSpot = {22, 10},
   Size = {32, 24}})

DefineCursor({
   Name = "cursor-arrow-ne",
   File = "graphics/ui/cursors/arrow_NE.png",
   HotSpot = {20, 2},
   Size = {32, 24}})

DefineCursor({
   Name = "cursor-arrow-n",
   File = "graphics/ui/cursors/arrow_N.png",
   HotSpot = {12, 2},
   Size = {32, 24}})

DefineCursor({
   Name = "cursor-arrow-nw",
   File = "graphics/ui/cursors/arrow_NW.png",
   HotSpot = {2, 2},
   Size = {32, 24}})

DefineCursor({
   Name = "cursor-arrow-w",
   File = "graphics/ui/cursors/arrow_W.png",
   HotSpot = {4, 10},
   Size = {32, 24}})

DefineCursor({
   Name = "cursor-arrow-s",
   File = "graphics/ui/cursors/arrow_S.png",
   HotSpot = {12, 22},
   Size = {32, 24}})

DefineCursor({
   Name = "cursor-arrow-sw",
   File = "graphics/ui/cursors/arrow_SW.png",
   HotSpot = {2, 18},
   Size = {32, 24}})

DefineCursor({
   Name = "cursor-arrow-se",
   File = "graphics/ui/cursors/arrow_SE.png",
   HotSpot = {20, 18},
   Size = {32, 24}})

DefineCursor({
   Name = "cursor-point",
   File = "graphics/ui/elites_claw.png",
   HotSpot = {1, 1}, 
   Size = {28, 32}})

DefineCursor({
   Name = "cursor-green-hair",
   File = "graphics/ui/cursors/green.png",
   HotSpot = {15, 15},
   Size = {32, 32}})

DefineCursor({
   Name = "cursor-yellow-hair",
   File = "graphics/ui/cursors/yellow.png",
   HotSpot = {15, 15},
   Size = {32, 32}})

DefineCursor({
   Name = "cursor-red-hair",
   File = "graphics/ui/cursors/red.png",
   HotSpot = {15, 15},
   Size = {32, 32}})
